package semantic_analysis

import (
	"fmt"
	"github.com/beego/beego/v2/client/orm"
	"github.com/rdlucklib/rdluck_tools/paging"
	"strings"
	"time"
)

type SaCompareClassify struct {
	SaCompareClassifyId int       `orm:"column(sa_compare_classify_id);pk" description:"分类ID"`
	ClassifyName        string    `description:"分类名称"`
	SysAdminId          int       `description:"创建人ID"`
	SysAdminName        string    `description:"创建人姓名"`
	CreateTime          time.Time `description:"创建时间"`
	ModifyTime          time.Time `description:"修改时间"`
}

var SaCompareClassifyColumns = struct {
	SaCompareClassifyId string
	ClassifyName        string
	SysAdminId          string
	SysAdminName        string
	CreateTime          string
	ModifyTime          string
}{
	SaCompareClassifyId: "sa_compare_classify_id",
	ClassifyName:        "classify_name",
	SysAdminId:          "sys_admin_id",
	SysAdminName:        "sys_admin_name",
	CreateTime:          "create_time",
	ModifyTime:          "modify_time",
}

func (m *SaCompareClassify) TableName() string {
	return "sa_compare_classify"
}

func (m *SaCompareClassify) Create() (err error) {
	o := orm.NewOrm()
	id, err := o.Insert(m)
	if err != nil {
		return
	}
	m.SaCompareClassifyId = int(id)
	return
}

func (m *SaCompareClassify) Update(cols []string) (err error) {
	o := orm.NewOrm()
	_, err = o.Update(m, cols...)
	return
}

func (m *SaCompareClassify) Del() (err error) {
	o := orm.NewOrm()
	sql := `DELETE FROM sa_compare_classify WHERE sa_compare_classify_id = ? LIMIT 1`
	_, err = o.Raw(sql, m.SaCompareClassifyId).Exec()
	return
}

func (m *SaCompareClassify) GetItemById(id int) (err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM sa_compare_classify WHERE sa_compare_classify_id = ? LIMIT 1`
	err = o.Raw(sql, id).QueryRow(&m)
	return
}

func (m *SaCompareClassify) GetItemByCondition(condition string, pars []interface{}) (err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM sa_compare_classify WHERE 1=1 `
	sql += condition
	sql += ` LIMIT 1`
	err = o.Raw(sql, pars).QueryRow(&m)
	return
}

func (m *SaCompareClassify) GetCountByCondition(condition string, pars []interface{}) (count int, err error) {
	o := orm.NewOrm()
	sql := fmt.Sprintf(`SELECT COUNT(1) FROM %s WHERE 1=1 %s`, m.TableName(), condition)
	err = o.Raw(sql, pars).QueryRow(&count)
	return
}

func (m *SaCompareClassify) GetItemsByCondition(condition string, pars []interface{}, fieldArr []string, orderRule string) (items []*SaCompareClassify, err error) {
	o := orm.NewOrm()
	fields := strings.Join(fieldArr, ",")
	if len(fieldArr) == 0 {
		fields = `*`
	}
	order := `ORDER BY create_time DESC`
	if orderRule != "" {
		order = ` ORDER BY ` + orderRule
	}
	sql := fmt.Sprintf(`SELECT %s FROM %s WHERE 1=1 %s %s`, fields, m.TableName(), condition, order)
	_, err = o.Raw(sql, pars).QueryRows(&items)
	return
}

func (m *SaCompareClassify) GetPageItemsByCondition(startSize, pageSize int, condition string, pars []interface{}, fieldArr []string, orderRule string) (total int, items []*SaCompareClassify, err error) {
	o := orm.NewOrm()
	fields := strings.Join(fieldArr, ",")
	if len(fieldArr) == 0 {
		fields = `*`
	}
	order := `ORDER BY create_time DESC`
	if orderRule != "" {
		order = ` ORDER BY ` + orderRule
	}
	sql := fmt.Sprintf(`SELECT %s FROM %s WHERE 1=1 %s %s`, fields, m.TableName(), condition, order)
	totalSql := `SELECT COUNT(1) total FROM (` + sql + `) z`
	if err = o.Raw(totalSql, pars).QueryRow(&total); err != nil {
		return
	}
	sql += ` LIMIT ?,?`
	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&items)
	return
}

type SaCompareClassifyAddReq struct {
	ClassifyName string `description:"分类名称"`
}

type SaCompareClassifyEditReq struct {
	SaCompareClassifyId int `description:"分类ID"`
	SaCompareClassifyAddReq
}

type SaCompareClassifyDelReq struct {
	SaCompareClassifyId int `description:"分类ID"`
}

type SaCompareClassifyPageListResp struct {
	List   []*SaCompareClassifyItem
	Paging *paging.PagingItem `description:"分页数据"`
}

type SaCompareClassifyItem struct {
	SaCompareClassifyId int              `description:"分类ID"`
	ClassifyName        string           `description:"分类名称"`
	SysAdminId          int              `description:"创建人ID"`
	SysAdminName        string           `description:"创建人姓名"`
	CreateTime          string           `description:"创建时间"`
	Children            []*SaCompareItem `description:"分类下的比对"`
}
